@@ -19,7 +19,11 @@ getIncidence <- function(cdm,
                          outcomeTable,
                          denominatorCohortId,
                          outcomeCohortId,
-                         interval,
+                         weeks,
+                         months,
+                         quarters,
+                         years,
+                         overall,
                          completeDatabaseIntervals,
                          outcomeWashout,
                          repeatedEvents,
@@ -27,32 +31,29 @@ getIncidence <- function(cdm,
                          analysisId,
                          strata,
                          includeOverallStrata) {
-  if (!is.null(outcomeWashout)) {
-    if (is.na(outcomeWashout)) {
+
+  if (!is.null(outcomeWashout) && is.na(outcomeWashout)) {
       outcomeWashout <- NULL
     }
-  }
 
   ## Analysis code
   # people in the relevant denominator
   # along with their outcomes
   studyPop <- cdm[[denominatorTable]] %>%
     dplyr::filter(.data$cohort_definition_id ==
-      .env$denominatorCohortId) %>%
+                    .env$denominatorCohortId) %>%
     dplyr::select(-"cohort_definition_id") %>%
     dplyr::left_join(
       cdm[[outcomeTable]] %>%
         dplyr::filter(.data$outcome_cohort_id ==
-          .env$outcomeCohortId) %>%
+                        .env$outcomeCohortId) %>%
         dplyr::select(-"outcome_cohort_id"),
       by = c(
         "subject_id",
         "cohort_start_date",
         "cohort_end_date"
       )
-    )
-
-  studyPop <- studyPop %>%
+    ) %>%
     dplyr::compute(
       name = paste0(tablePrefix, "_inc_5"),
       temporary = FALSE,
@@ -69,104 +70,99 @@ getIncidence <- function(cdm,
   # participants without an outcome
   studyPopNoOutcome <- studyPop %>%
     dplyr::filter(is.na(.data$outcome_start_date) &
-      is.na(.data$outcome_prev_end_date))
+                  is.na(.data$outcome_prev_end_date))
 
   # participants with an outcome
   # if outcome starts before cohort end date
   # update cohort_end_date
   studyPopOutcome <- studyPop %>%
     dplyr::filter(!is.na(.data$outcome_start_date) |
-      !is.na(.data$outcome_prev_end_date)) %>%
-    dplyr::mutate(cohort_end_date = dplyr::if_else(
-      !is.na(.data$outcome_start_date) &
-        .data$outcome_start_date < .data$cohort_end_date,
+                    !is.na(.data$outcome_prev_end_date)) %>%
+    dplyr::mutate(cohort_end_date = dplyr::coalesce(
       .data$outcome_start_date,
       .data$cohort_end_date
     ))
 
- nStudyPopOutcome <- studyPopOutcome %>%
+  nStudyPopOutcome <- studyPopOutcome %>%
     utils::head(10) %>%
     dplyr::tally() %>%
     dplyr::pull("n")
 
 
- if(nStudyPopOutcome > 0){
-  if (is.null(outcomeWashout)) {
-    # exclude anyone with a previous outcome
-    studyPopOutcome <- studyPopOutcome %>%
-      dplyr::filter(is.na(.data$outcome_prev_end_date) &
-        .data$cohort_start_date <= .data$cohort_end_date)
-  } else {
-    # otherwise add the washout to the previous outcome
-    outcomeWashoutPlusOne <- as.integer(outcomeWashout + 1)
-    studyPopOutcome <- studyPopOutcome %>%
-      dplyr::mutate(outcome_prev_end_date = as.Date(.data$outcome_prev_end_date)) %>%
-      dplyr::mutate(outcome_prev_end_date = dplyr::if_else(
-        is.na(.data$outcome_prev_end_date),
-        as.Date(.data$outcome_prev_end_date),
-        as.Date(!!CDMConnector::dateadd("outcome_prev_end_date",
-          {{ outcomeWashoutPlusOne }},
-          interval = "day"
-        ))
-      )) %>%
-      dplyr::mutate(cohort_start_date = dplyr::if_else(
-        is.na(.data$outcome_prev_end_date) |
-          (.data$cohort_start_date > .data$outcome_prev_end_date),
-        .data$cohort_start_date,
-        .data$outcome_prev_end_date
-      )) %>%
-      dplyr::filter(.data$cohort_start_date <= .data$cohort_end_date)
-    if (repeatedEvents == FALSE &&
-      sum(!is.na(studyPopOutcome %>%
-        dplyr::pull(.data$outcome_start_date))) > 0) {
+  if(nStudyPopOutcome > 0){
+    if (is.null(outcomeWashout)) {
+      # exclude anyone with a previous outcome
       studyPopOutcome <- studyPopOutcome %>%
-        dplyr::group_by(.data$subject_id) %>%
-        dplyr::mutate(events_post = sum(dplyr::if_else(
-          !is.na(.data$outcome_start_date), 1, 0
-        ), na.rm = TRUE))
-
-      studyPopOutcomeWH <- studyPopOutcome %>%
-        dplyr::group_by(.data$subject_id) %>%
-        dplyr::filter(.data$events_post == 0)
-
-      studyPopOutcomeWH <- studyPopOutcomeWH %>%
-        dplyr::compute(
-          name = paste0(tablePrefix, "_inc_5a"),
-          temporary = FALSE,
-          overwrite = TRUE
-        )
-
-      studyPopOutcome <- dplyr::union_all(
-        # with history of outcome, without outcome in follow up
-        studyPopOutcomeWH,
-        # with outcome in follow up - limit to first
-        studyPopOutcome %>%
-          dplyr::filter(.data$events_post >= 1) %>%
+        dplyr::filter(is.na(.data$outcome_prev_end_date) &
+                        .data$cohort_start_date <= .data$cohort_end_date)
+    } else {
+      # otherwise add the washout to the previous outcome
+      outcomeWashoutPlusOne <- as.integer(outcomeWashout + 1)
+      studyPopOutcome <- studyPopOutcome %>%
+        dplyr::mutate(outcome_prev_end_date =
+                        as.Date(.data$outcome_prev_end_date)) %>%
+        dplyr::mutate(outcome_prev_end_date = dplyr::if_else(
+          is.na(.data$outcome_prev_end_date),
+          as.Date(.data$outcome_prev_end_date),
+          as.Date(!!CDMConnector::dateadd("outcome_prev_end_date",
+                                          {{ outcomeWashoutPlusOne }},
+                                          interval = "day"
+          ))
+        )) %>%
+        dplyr::mutate(cohort_start_date = dplyr::if_else(
+          is.na(.data$outcome_prev_end_date) |
+            (.data$cohort_start_date > .data$outcome_prev_end_date),
+          .data$cohort_start_date,
+          .data$outcome_prev_end_date
+        )) %>%
+        dplyr::filter(.data$cohort_start_date <= .data$cohort_end_date)
+      if (repeatedEvents == FALSE &&
+          sum(!is.na(studyPopOutcome %>%
+                     dplyr::pull(.data$outcome_start_date))) > 0) {
+        studyPopOutcome <- studyPopOutcome %>%
           dplyr::group_by(.data$subject_id) %>%
-          dplyr::filter(.data$cohort_start_date ==
-            min(.data$cohort_start_date, na.rm = TRUE)) %>%
-          dplyr::ungroup()
-      ) %>%
-        dplyr::select(-"events_post")
+          dplyr::mutate(events_post = sum(dplyr::if_else(
+            !is.na(.data$outcome_start_date), 1, 0
+          ), na.rm = TRUE))
+
+        studyPopOutcomeWH <- studyPopOutcome %>%
+          dplyr::group_by(.data$subject_id) %>%
+          dplyr::filter(.data$events_post == 0) %>%
+          dplyr::compute(
+            name = paste0(tablePrefix, "_inc_5a"),
+            temporary = FALSE,
+            overwrite = TRUE
+          )
+
+        studyPopOutcome <- dplyr::union_all(
+          # with history of outcome, without outcome in follow up
+          studyPopOutcomeWH,
+          # with outcome in follow up - limit to first
+          studyPopOutcome %>%
+            dplyr::filter(.data$events_post >= 1) %>%
+            dplyr::group_by(.data$subject_id) %>%
+            dplyr::filter(.data$cohort_start_date ==
+                            min(.data$cohort_start_date, na.rm = TRUE)) %>%
+            dplyr::ungroup()
+        ) %>%
+          dplyr::select(-"events_post")
+      }
     }
+
+    # set cohort end date
+    studyPopOutcome <- studyPopOutcome %>%
+      dplyr::mutate(cohort_end_date = dplyr::if_else(
+        !is.na(.data$outcome_start_date),
+        .data$outcome_start_date,
+        .data$cohort_end_date
+      ))
+
   }
 
-  # set cohort end date
-  studyPopOutcome <- studyPopOutcome %>%
-    dplyr::mutate(cohort_end_date = dplyr::if_else(
-      !is.na(.data$outcome_start_date),
-      .data$outcome_start_date,
-      .data$cohort_end_date
-    ))
-
- }
-
   # combine those without an outcome back with those with an outcome
   # this is now our study population to get the incidence rates for
-  studyPopDb <- studyPopNoOutcome %>%
-    dplyr::union_all(studyPopOutcome)
-
-  studyPop <- studyPopDb %>%
+  studyPop <- studyPopNoOutcome %>%
+    dplyr::union_all(studyPopOutcome) %>%
     dplyr::collect()
   attrition <- recordAttrition(
     table = studyPop,
@@ -175,38 +171,77 @@ getIncidence <- function(cdm,
     reason = "Excluded due to prior event (do not pass outcome washout during study period)",
     existingAttrition = attrition
   )
+# intervals to estimate
+interval <- c(
+  "weeks" = weeks,
+  "months" = months,
+  "quarters" = quarters,
+  "years" = years,
+  "overall" = overall
+)
+interval <- names(interval[interval])
 
   # study dates
   # based on the earliest start and latest end of those
   # in the relevant denominator
+  studyDays <- list()
   if (nrow(studyPop) > 0) {
     startEnd <- studyPop %>%
       dplyr::summarise(
         min = as.Date(min(.data$cohort_start_date, na.rm = TRUE)),
         max = as.Date(max(.data$cohort_end_date, na.rm = TRUE))
       )
-
-    if (interval == "overall") {
+    if ("weeks" %in% interval) {
+      studyDays[["weeks"]] <- getStudyDays(
+        startDate = startEnd$min,
+        endDate = startEnd$max,
+        timeInterval = "weeks",
+        completeDatabaseIntervals = completeDatabaseIntervals
+      )
+    }
+    if ("months" %in% interval) {
+      studyDays[["months"]] <- getStudyDays(
+        startDate = startEnd$min,
+        endDate = startEnd$max,
+        timeInterval = "months",
+        completeDatabaseIntervals = completeDatabaseIntervals
+      )
+    }
+    if ("quarters" %in% interval) {
+      studyDays[["quarters"]] <- getStudyDays(
+        startDate = startEnd$min,
+        endDate = startEnd$max,
+        timeInterval = "quarters",
+        completeDatabaseIntervals = completeDatabaseIntervals
+      )
+    }
+    if ("years" %in% interval) {
+      studyDays[["years"]] <- getStudyDays(
+        startDate = startEnd$min,
+        endDate = startEnd$max,
+        timeInterval = "years",
+        completeDatabaseIntervals = completeDatabaseIntervals
+      )
+    }
+    if ("overall" %in% interval) {
       # note, full periods argument does not apply
       # for overall we just go from start to end
-      studyDays <- dplyr::tibble(
+      studyDays[["overall"]] <- dplyr::tibble(
         time = "overall",
         start_time = startEnd$min,
         end_time = startEnd$max
       )
-    } else {
-      studyDays <- getStudyDays(
-        startDate = startEnd$min,
-        endDate = startEnd$max,
-        timeInterval = interval,
-        completeDatabaseIntervals = completeDatabaseIntervals
-      )
     }
-  } else {
-    studyDays <- dplyr::tibble()
+  } else{
+    # empty population
+    studyDays[["none"]] <- dplyr::tibble()
+  }
+ if (nrow(dplyr::bind_rows(studyDays)) == 0) {
+   # no study days
+    studyDays[["none"]] <- dplyr::tibble()
   }
 
-  if (nrow(studyDays) == 0) {
+  if ("none" %in% names(studyDays)) {
     # if no study days we´ll return an empty tibble
     ir <- dplyr::tibble()
 
@@ -219,10 +254,10 @@ getIncidence <- function(cdm,
     )
   }
 
-  if (nrow(studyDays) > 0) {
+  if (!"none" %in% names(studyDays)) {
     # drop for complete database intervals requirement
-    minStartDate <- min(studyDays$start_time)
-    maxStartDate <- max(studyDays$end_time)
+    minStartDate <- min(dplyr::bind_rows(studyDays)$start_time)
+    maxStartDate <- max(dplyr::bind_rows(studyDays)$end_time )
     studyPop <- studyPop %>%
       dplyr::filter(.data$cohort_end_date >= .env$minStartDate,
                     .data$cohort_start_date <= .env$maxStartDate)
@@ -238,43 +273,40 @@ getIncidence <- function(cdm,
     # fetch incidence rates
     # looping through each time interval
     ir <- list()
-    for (i in seq_len(nrow(studyDays))) {
-      workingStartTime <- studyDays$start_time[i]
-      workingEndTime <- studyDays$end_time[i]
+    for(j in seq_along(interval)){
+      workingInterval <- interval[j]
+      workingStudyDays <- studyDays[[workingInterval]]
+    for (i in seq_len(nrow(workingStudyDays))) {
+      workingStartTime <- workingStudyDays$start_time[i]
+      workingEndTime <- workingStudyDays$end_time[i]
 
       # people who can contribute to the period
       workingPop <- studyPop %>%
-        dplyr::filter(.data$cohort_end_date >= .env$workingStartTime) %>%
-        dplyr::filter(.data$cohort_start_date <= .env$workingEndTime)
+        dplyr::filter(.data$cohort_end_date >= .env$workingStartTime,
+                      .data$cohort_start_date <= .env$workingEndTime)
 
       if (nrow(workingPop) > 0) {
         # individuals start date for this period
         # which could be start of the period or later
         workingPop <- workingPop %>%
           dplyr::mutate(tStart = dplyr::if_else(.data$cohort_start_date <= .env$workingStartTime,
-            as.Date(.env$workingStartTime),
-            as.Date(.data$cohort_start_date)
-          )) %>%
+                                                as.Date(.env$workingStartTime),
+                                                as.Date(.data$cohort_start_date)
+          ),
           # individuals end date for this period
           # end of the period or earlier
-          dplyr::mutate(
             tEnd =
               dplyr::if_else(.data$cohort_end_date >= .env$workingEndTime,
-                as.Date(.env$workingEndTime),
-                as.Date(.data$cohort_end_date)
+                             as.Date(.env$workingEndTime),
+                             as.Date(.data$cohort_end_date)
               )
-          )
-
-        # compute working days
-        workingPop <- workingPop %>%
+          ) %>%
           dplyr::mutate(workingDays = as.numeric(difftime(
             .data$tEnd,
             .data$tStart,
             units = "days"
-          )) + 1)
-
+          )) + 1)  %>%
         # erase outcome_start_date if not during period
-        workingPop <- workingPop %>%
           dplyr::mutate(outcome_start_date = dplyr::if_else(
             .data$outcome_start_date <= .data$tEnd &
               .data$outcome_start_date >= .data$tStart,
@@ -283,40 +315,44 @@ getIncidence <- function(cdm,
           ))
 
         if(length(strata)==0 || includeOverallStrata == TRUE){
-        ir[[paste0(i)]] <- workingPop %>%
-          dplyr::summarise(
-            n_persons = dplyr::n_distinct(.data$subject_id),
-            person_days = sum(.data$workingDays),
-            n_events = sum(!is.na(.data$outcome_start_date))
-          ) %>%
-          dplyr::mutate(incidence_start_date = .env$workingStartTime) %>%
-          dplyr::mutate(incidence_end_date = .env$workingEndTime)
+          ir[[paste0(i, "_", j)]] <- workingPop %>%
+            dplyr::summarise(
+              denominator_count = dplyr::n_distinct(.data$subject_id),
+              person_days = sum(.data$workingDays),
+              outcome_count = sum(!is.na(.data$outcome_start_date))
+            ) %>%
+            dplyr::mutate(incidence_start_date = .env$workingStartTime,
+                          incidence_end_date = .env$workingEndTime,
+                          analysis_interval = .env$workingInterval)
         } else {
-          ir[[paste0(i)]] <- dplyr::tibble()
+          ir[[paste0(i, "_", j)]] <- dplyr::tibble()
         }
 
-
         if(length(strata)>=1){
-          ir[[paste0(i)]] <- ir[[paste0(i)]] %>%
-            dplyr::mutate(strata_name = "Overall",
-                          strata_level = "Overall")
-          for(j in seq_along(strata)){
-          ir[[paste0(i)]] <-  dplyr::bind_rows(ir[[paste0(i)]],
-                             getStratifiedIncidenceResult(workingPop = workingPop,
-                                                 workingStrata = strata[[j]],
-                                                 workingStartTime = workingStartTime,
-                                                 workingEndTime= workingEndTime))
+          ir[[paste0(i, "_", j)]] <- ir[[paste0(i, "_", j)]] %>%
+            omopgenerics::uniteStrata()
+          for(k in seq_along(strata)){
+            ir[[paste0(i, "_", j, "_", k)]] <-  dplyr::bind_rows(ir[[paste0(i, "_", j)]],
+                                  getStratifiedIncidenceResult(workingPop = workingPop,
+                                                                              workingStrata = strata[[k]],
+                                                                              workingStartTime = workingStartTime,
+                                                                              workingEndTime= workingEndTime,
+                                                                              workingInterval = workingInterval))
           }
         }
 
       }
-    }
-    ir <- dplyr::bind_rows(ir) %>%
-      dplyr::mutate(person_years = round(.data$person_days / 365.25, 3)) %>%
+    }}
+    ir <- dplyr::bind_rows(ir)
+    if(nrow(ir) > 0){
+    ir <- ir %>%
       dplyr::mutate(
+        person_years = round(.data$person_days / 365.25, 3),
         incidence_100000_pys =
-          round(((.data$n_events / .data$person_years) * 100000), 3)
+          round(((.data$outcome_count / .data$person_years) * 100000), 3)
       )
+    }
+
   }
 
   # study design related variables
@@ -326,7 +362,6 @@ getIncidence <- function(cdm,
   analysisSettings <- dplyr::tibble(
     analysis_outcome_washout = .env$outcomeWashout,
     analysis_repeated_events = .env$repeatedEvents,
-    analysis_interval = .env$interval,
     analysis_complete_database_intervals = .env$completeDatabaseIntervals
   )
   studyPop <- studyPop %>%
@@ -347,21 +382,18 @@ getIncidence <- function(cdm,
 
 
 getStratifiedIncidenceResult <- function(workingPop, workingStrata,
-                                workingStartTime, workingEndTime){
+                                         workingStartTime, workingEndTime,
+                                         workingInterval){
   workingPop %>%
     dplyr::group_by(dplyr::pick(.env$workingStrata)) %>%
     dplyr::summarise(
-      n_persons = dplyr::n_distinct(.data$subject_id),
+      denominator_count = dplyr::n_distinct(.data$subject_id),
       person_days = sum(.data$workingDays),
-      n_events = sum(!is.na(.data$outcome_start_date))
+      outcome_count = sum(!is.na(.data$outcome_start_date))
     ) %>%
     dplyr::ungroup() %>%
-    dplyr::mutate(incidence_start_date = .env$workingStartTime) %>%
-    dplyr::mutate(incidence_end_date = .env$workingEndTime) %>%
-    tidyr::unite("strata_level",
-                 c(dplyr::all_of(.env$workingStrata)),
-                 remove = FALSE, sep = " and ") %>%
-    dplyr::mutate(strata_name = !!paste0(workingStrata, collapse = " and ")) %>%
-    dplyr::relocate("strata_level", .after = "strata_name") %>%
-    dplyr::select(!dplyr::any_of(workingStrata))
+    dplyr::mutate(incidence_start_date = .env$workingStartTime,
+                  incidence_end_date = .env$workingEndTime,
+                  analysis_interval = .env$workingInterval) %>%
+    omopgenerics::uniteStrata(cols = workingStrata)
 }
