@@ -3,7 +3,7 @@ test_that("basic plots", {
   skip_if_not_installed("ggplot2")
   skip_if_not_installed("scales")
 
-  cdm <- mockIncidencePrevalenceRef(sampleSize = 100)
+  cdm <- mockIncidencePrevalence(sampleSize = 100)
   cdm <- generateDenominatorCohortSet(
     cdm = cdm, name = "denominator",
     cohortDateRange = c(as.Date("2008-01-01"), as.Date("2018-01-01"))
@@ -13,7 +13,7 @@ test_that("basic plots", {
   inc <- estimateIncidence(
     cdm = cdm,
     denominatorTable = "denominator",
-    outcomeTable = "outcome", minCellCount = 0
+    outcomeTable = "outcome"
   )
   plot <- plotIncidence(inc)
   expect_true(ggplot2::is.ggplot(plot))
@@ -29,7 +29,7 @@ test_that("basic plots", {
   inc <- estimateIncidence(
     cdm = cdm,
     denominatorTable = "denominator",
-    outcomeTable = "outcome", interval = "overall", minCellCount = 0
+    outcomeTable = "outcome", interval = "overall"
   )
   prev <- estimatePrevalence(
     cdm = cdm, interval = "years",
@@ -40,7 +40,8 @@ test_that("basic plots", {
   expect_true(ggplot2::is.ggplot(plot))
 
   # prevalence plot
-  plot <- plotPrevalence(prev, x = "denominator_age_group")
+  plot <- plotPrevalence(prev, x = "prevalence_start_date",
+                         facet = "denominator_age_group")
   expect_true(ggplot2::is.ggplot(plot))
 
   # with a different x axis
@@ -55,7 +56,7 @@ test_that("basic plots", {
   prev <- estimatePrevalence(
     cdm = cdm, interval = "years",
     denominatorTable = "denominator",
-    outcomeTable = "outcome", minCellCount = 0
+    outcomeTable = "outcome"
   )
   plot <- plotPrevalence(prev,
                          x = "denominator_age_group"
@@ -63,40 +64,45 @@ test_that("basic plots", {
   expect_true(ggplot2::is.ggplot(plot))
 
   # empty plot if an empty result
-  expect_true(ggplot2::is.ggplot(
+  expect_warning(expect_true(ggplot2::is.ggplot(
     plotIncidence(inc |>
-    dplyr::filter(result_id == 0))))
-  expect_true(ggplot2::is.ggplot(
+    dplyr::filter(result_id == 0)))))
+  expect_warning(expect_true(ggplot2::is.ggplot(
     plotPrevalence(prev |>
-                    dplyr::filter(result_id == 0))))
+                    dplyr::filter(result_id == 0)))))
 
   # other result type
-  expect_true(ggplot2::is.ggplot(
-    plotIncidence(prev)))
-  expect_true(ggplot2::is.ggplot(
-    plotPrevalence(inc)))
+  expect_warning(expect_true(ggplot2::is.ggplot(
+    plotIncidence(prev))))
+  expect_warning(expect_true(ggplot2::is.ggplot(
+    plotPrevalence(inc))))
 
 
   # mixed result types
   expect_true(ggplot2::is.ggplot(plotPrevalence(omopgenerics::bind(inc,
-                     prev))))
+                                    prev),
+                 x = "denominator_age_group"
+  )))
   expect_true(ggplot2::is.ggplot(plotIncidence(omopgenerics::bind(inc,
-                                                                   prev))))
+                                                                   prev),
+                                                x = "denominator_age_group"
+  )))
 
   # imported result
   result_path <- tempdir("result_to_plot")
   result <- omopgenerics::bind(inc, prev)
-  unique(omopgenerics::settings(result) |> dplyr::pull("min_cell_count")) |> as.numeric()
+  omopgenerics::exportSummarisedResult(result, path = result_path,
+                                       minCellCount = 5)
 
-  omopgenerics::exportSummarisedResult(result, path = result_path, minCellCount = 0)
+  result <- result |> omopgenerics::suppress(5)
   result_imported <-  omopgenerics::importSummarisedResult(result_path)
 
-  # expect_identical(
-  #   plotIncidence(result),
-  #   plotIncidence(result_imported))
-  # expect_identical(
-  #   plotPrevalence(result),
-  #   plotPrevalence(result_imported))
+  expect_identical(
+    plotIncidence(result, x = "denominator_age_group"),
+    plotIncidence(result_imported, x = "denominator_age_group"))
+  expect_identical(
+    plotPrevalence(result,  x = "denominator_age_group"),
+    plotPrevalence(result_imported, x = "denominator_age_group"))
 
   CDMConnector::cdm_disconnect(cdm)
 })
@@ -105,7 +111,7 @@ test_that("plot facets", {
   skip_on_cran()
   skip_if_not_installed("ggplot2")
   skip_if_not_installed("scales")
-  cdm <- mockIncidencePrevalenceRef(sampleSize = 1000)
+  cdm <- mockIncidencePrevalence(sampleSize = 1000)
   cdm <- generateDenominatorCohortSet(
     cdm = cdm,name = "denominator",
     ageGroup = list(
@@ -113,12 +119,6 @@ test_that("plot facets", {
       c(31, 100)
     )
   )
-  inc <- estimateIncidence(
-    cdm = cdm,
-    denominatorTable = "denominator",
-    outcomeTable = "outcome", minCellCount = 0
-  )
-  plot_orig <- plotIncidence(inc, facet = "denominator_age_group")
   inc <- estimateIncidence(
     cdm = cdm,
     denominatorTable = "denominator",
@@ -160,7 +160,7 @@ test_that("plot colour", {
   skip_on_cran()
   skip_if_not_installed("ggplot2")
   skip_if_not_installed("scales")
-  cdm <- mockIncidencePrevalenceRef(sampleSize = 1000)
+  cdm <- mockIncidencePrevalence(sampleSize = 1000)
   cdm <- generateDenominatorCohortSet(
     cdm = cdm,name = "denominator",
     ageGroup = list(
@@ -175,8 +175,7 @@ test_that("plot colour", {
   )
 
   plot <- plotIncidence(inc,
-                        colour = "denominator_age_group",
-                        colour_name = "Age group"
+                        colour = "denominator_age_group"
   )
   expect_true(ggplot2::is.ggplot(plot))
 
@@ -211,7 +210,7 @@ test_that("plot options", {
   skip_on_cran()
   skip_if_not_installed("ggplot2")
   skip_if_not_installed("scales")
-  cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
+  cdm <- mockIncidencePrevalence(sampleSize = 10000)
   cdm <- generateDenominatorCohortSet(
     cdm = cdm,
     name = "denominator",
@@ -228,7 +227,6 @@ test_that("plot options", {
                       'facetNcols' = 1)
   plot <- plotIncidence(inc,
                         colour = "denominator_age_group",
-                        colour_name = "Age group",
                         options = plotOptions)
   expect_true(ggplot2::is.ggplot(plot))
 
@@ -236,8 +234,7 @@ test_that("plot options", {
   prev <- estimatePrevalence(
     cdm = cdm, interval = "years",
     denominatorTable = "denominator",
-    outcomeTable = "outcome",
-    minCellCount = 0
+    outcomeTable = "outcome"
   )
 
   plot <- plotPrevalence(prev,
@@ -247,7 +244,54 @@ test_that("plot options", {
 
   expect_true(ggplot2::is.ggplot(plot))
 
+  plot <- plotPrevalence(prev,
+                         colour = c("denominator_age_group",
+                                    "denominator_sex"),
+                         options = list("line" = FALSE))
+  expect_true(ggplot2::is.ggplot(plot))
+
+  plot <- plotPrevalence(prev,
+                         colour = c("denominator_age_group",
+                                    "denominator_sex"),
+                         ribbon = TRUE,
+                         options = list("point" = FALSE))
+  expect_true(ggplot2::is.ggplot(plot))
+
   CDMConnector::cdm_disconnect(cdm)
 })
 
+test_that("y axis", {
+  skip_on_cran()
+  skip_if_not_installed("ggplot2")
+  skip_if_not_installed("scales")
 
+  cdm <- mockIncidencePrevalence(sampleSize = 100)
+  cdm <- generateDenominatorCohortSet(
+    cdm = cdm, name = "denominator",
+    cohortDateRange = c(as.Date("2008-01-01"), as.Date("2018-01-01"))
+  )
+
+  # incidence plot
+  inc <- estimateIncidence(
+    cdm = cdm,
+    denominatorTable = "denominator",
+    outcomeTable = "outcome"
+  )
+  plot <- plotIncidence(inc, x = "denominator_age_group", y = "denominator_count", facet = "incidence_start_date")
+  expect_true(ggplot2::is.ggplot(plot))
+
+  plot <- plotIncidence(inc, options = list(line = FALSE), ribbon = TRUE, y = "person_days")
+  expect_true(ggplot2::is.ggplot(plot))
+
+  # prevalence plot
+  prev <- estimatePeriodPrevalence(
+    cdm = cdm,
+    denominatorTable = "denominator",
+    outcomeTable = "outcome"
+  )
+  plot <- plotPrevalence(prev, x = "denominator_age_group", y = "outcome_count", facet = "denominator_sex")
+  expect_true(ggplot2::is.ggplot(plot))
+
+
+  CDMConnector::cdm_disconnect(cdm)
+})
